@@ -19,6 +19,10 @@ class BaseStorage:  # pragma: no cover
 
 
 class StorageFile:
+    """
+    The file obect returned by the storage.
+    """
+
     def __init__(self, *, name: str, storage: BaseStorage):
         self._name = name
         self._storage = storage
@@ -57,3 +61,32 @@ class StorageFile:
 
     def __str__(self) -> str:
         return self.name
+
+
+class StorageImage(StorageFile):
+    """
+    Inherits features of `StorageFile` and adds image specific properties.
+    """
+
+    def __init__(
+        self, *, name: str, storage: BaseStorage, height: int, width: int
+    ) -> None:
+        super().__init__(name=name, storage=storage)
+        self._width = width
+        self._height = height
+
+    @property
+    def height(self) -> int:
+        """
+        Image height in pixels.
+        """
+
+        return self._height
+
+    @property
+    def width(self) -> int:
+        """
+        Image width in pixels.
+        """
+
+        return self._width
