@@ -9,6 +9,11 @@ _filename_ascii_strip_re = re.compile(r"[^A-Za-z0-9_.-]")
 
 
 class FileSystemStorage(BaseStorage):
+    """
+    File system storage which stores files in the local filesystem.
+    You might want to use this with the `FileType` type.
+    """
+
     default_chunk_size = 64 * 1024
 
     def __init__(self, path: str):
@@ -17,19 +22,34 @@ class FileSystemStorage(BaseStorage):
             self._path.mkdir()
 
     def get_name(self, name: str) -> str:
+        """
+        Get the normalized name of the file.
+        """
         return secure_filename(name)
 
     def get_path(self, name: str) -> str:
+        """
+        Get full path to the file.
+        """
         return str(self._path / Path(name))
 
     def get_size(self, name: str) -> int:
+        """
+        Get file size in bytes.
+        """
         return (self._path / name).stat().st_size
 
     def open(self, name: str) -> BinaryIO:
+        """
+        Open a file handle of the file object in binary mode.
+        """
         path = self._path / Path(name)
         return open(path, "rb")
 
     def write(self, file: BinaryIO, name: str) -> None:
+        """
+        Write input file which is opened in binary mode to destination.
+        """
         filename = secure_filename(name)
         path = self._path / Path(filename)
 
