@@ -10,9 +10,21 @@ from sqlalchemy.types import TypeDecorator, Unicode
 from sqlalchemy_fields.exceptions import ValidationException
 
 
-class Email(TypeDecorator):
+class EmailType(TypeDecorator):
     """
-    Email type with validation using email-validator package.
+    Email type with validation using `email-validator` package.
+
+    ???+ usage
+        ```python
+        from sqlalchemy_fields.types import EmailType
+
+        class Example(Base):
+            __tablename__ = "example"
+
+            id = Column(Integer, primary_key=True)
+            email = Column(EmailType())
+            billing_email = Column(EmailType(length=128))
+        ```
     """
 
     impl = Unicode
