@@ -7,9 +7,21 @@ from sqlalchemy.types import TypeDecorator, Unicode
 from sqlalchemy_fields.exceptions import ValidationException
 
 
-class URL(TypeDecorator):
+class URLType(TypeDecorator):
     """
-    URL type with validation.
+    URL type with validation using Python standard library.
+
+    ???+ usage
+        ```python
+        from sqlalchemy_fields.types import URLType
+
+        class Example(Base):
+            __tablename__ = "example"
+
+            id = Column(Integer, primary_key=True)
+            url = Column(URLType())
+            website = Column(URLType(length=1024))
+        ```
     """
 
     impl = Unicode
